@@ -5,7 +5,7 @@ class Distro(Module):
     '''Send Public Key to Target
     kw:
         usr : User name
-        pub : Piblic key
+        pub : Public key
     '''
 
     def deploy(self, target, **kw):
