@@ -17,8 +17,9 @@ class Distro(Module):
         return 'Download'
 
     def deploy(self, target, **kw):
-        url, dst = kw['url'], kw.get('dst')
-        dst = dst or 'downloaded'
+        url = kw['url']
+        dst = kw.get('dst', 'downloaded')
+
         try:
             ret, out, err = target.run(f'wget2 -q {url} -O {dst}')
             if ret!=0:
@@ -41,6 +42,5 @@ class Distro(Module):
                         msg = err[0]
                         error(msg)
                         raise RuntimeError(msg)
-        # target(f'ls -l {dst}')
         return True
 
