@@ -10,11 +10,7 @@ class Distro(Module):
         user = target.login.name
         kernel = target.kernel
         python = target.run('python3 -V')[1][0]
-        with logger.quiet():
-            try:
-                addr = target.net.addr
-            except:
-                addr = '!'
+        addr = target.net.addr or '!'
 
         infos =  f'''
         target : {target}
