@@ -10,7 +10,7 @@ class Distro(Module):
         )
 
 
-class Debian(Module):
+class Debian(Distro):
     def do_deploy(self, target, **kw):
         return self.install(target,
             pkg = 'pip setuptools venv',
